ApiUserRoomResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ApiUserRoomResponse({String? id, String? avatar, String? username, String? nickName, String? displayName, bool? isOnline, int? defautlStatus, List<String>? roles})
ApiUserRoomResponse.fromJson(Map<String, dynamic> json)
factory

Properties

avatar String?
final
defautlStatus int?
final
displayName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
isOnline bool?
final
nickName String?
final
roles List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited