AttachmentsModel class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- attachId ↔ String?
-
getter/setter pair
- desciption ↔ String?
-
getter/setter pair
- durationSeconds ↔ int?
-
@ time in seconds
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
@ id attachments (send id = null or '')
getter/setter pair
- messageId ↔ String?
-
getter/setter pair
- name ↔ String?
-
@ name file
getter/setter pair
- revoke ↔ int?
-
@ 1 revoke for sender, 2 revoke for all group
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeByte ↔ int?
-
@ sizeByte file
getter/setter pair
- typeAttachment ↔ int?
-
@ video = 1, audio = 2, image = 3, file = 4, other = 5
getter/setter pair
- url ↔ String?
-
url file
getter/setter pair
- urlPreView ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited