ChatRoomItem class

Annotations
  • @JsonSerializable.new()

Constructors

ChatRoomItem({String? id, String? createdOn, String? name, String? topic, String? description, String? image, String? ownerId, int? roomType, int? typeOfGroup, int? participantCount, int? unreadCount, bool? hasUnreadMessage, bool? isFavorite, ParticipantInfoModel? participantInfo, List<String>? tags, LastMessageModel? lastMessage, bool? notifyStatus})
ChatRoomItem.fromJson(Map<String, dynamic> json)
factory

Properties

createdOn String?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasUnreadMessage bool?
getter/setter pair
id String?
getter/setter pair
image String?
getter/setter pair
isFavorite bool?
getter/setter pair
lastMessage LastMessageModel?
getter/setter pair
listUserActive List<String>?
getter/setter pair
name String?
getter/setter pair
notifyStatus bool?
getter/setter pair
ownerId String?
getter/setter pair
participantCount int?
getter/setter pair
participantInfo ParticipantInfoModel?
getter/setter pair
roomType int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>?
final
topic String?
getter/setter pair
typeOfGroup int?
getter/setter pair
unreadCount int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited