LastMessageModel class

Annotations
  • @JsonSerializable.new()

Constructors

LastMessageModel({String? id, String? message, String? userId, String? fullName, String? time, String? userName, String? nickName, String? avatar, bool? isEdited, String? lastEditTime, int? type, List<AttachmentsModel>? attachments, bool? isDeleted})
LastMessageModel.fromJson(Map<String, dynamic> json)
factory

Properties

attachments List<AttachmentsModel>?
final
avatar String?
getter/setter pair
fullName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
isDeleted bool?
getter/setter pair
isEdited bool?
getter/setter pair
lastEditTime String?
getter/setter pair
message String?
getter/setter pair
nickName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String?
getter/setter pair
type int?
getter/setter pair
userId String?
getter/setter pair
userName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited