LoginResponse class

Annotations
  • @JsonSerializable.new()

Constructors

LoginResponse({required String access_token, required int expires_in, String? membership, String? refresh_token})
LoginResponse.fromJson(Map<String, dynamic> json)
factory

Properties

access_token String
final
expires_in int
final
hashCode int
The hash code for this object.
no setterinherited
membership String?
final
refresh_token String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited