PinMessageModel class

Annotations
  • @JsonSerializable.new()

Constructors

PinMessageModel({String? messageId, String? roomId, String? userId, String? displayName, String? messageContent})
PinMessageModel.fromJson(Map<String, dynamic> json)
factory

Properties

displayName String?
@ display name sender
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messageContent String?
@ content pin message
getter/setter pair
messageId String?
@ message id pin
getter/setter pair
roomId String?
@ id group
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
@ id sender
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited