ProfileResponse class

Annotations
  • @JsonSerializable.new()

Properties

avatar String?
getter/setter pair
dateOfBirth String?
@ ex: 2023-10-06T02:46:24.015Z
getter/setter pair
email String?
getter/setter pair
gender int?
@ gender 0: male, 1: female
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasPassword bool?
getter/setter pair
id String?
@ id user
getter/setter pair
isExternal bool?
getter/setter pair
isFriend bool?
@ status is friend
getter/setter pair
name String?
getter/setter pair
phoneNumber String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited