ReceiveResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ReceiveResponse({String? messageId, String? groupId, String? userId, String? reactionCode, String? revokeStatus, String? attachmentId})
@ Listens for message seen @ Listens for incoming react message. @ Listens for incoming revoke attachment message.
ReceiveResponse.fromJson(Map<String, dynamic> json)
factory

Properties

attachmentId String?
@ id attachment
getter/setter pair
groupId String?
@ id group
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messageId String?
@ message id
getter/setter pair
reactionCode String?
@ name icon react (get by api list emoji)
getter/setter pair
revokeStatus String?
@ 2 - Revoke for sender, 3 - Revoke all group
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
@ id user
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited