DataItemJoin class

Annotations
  • @JsonSerializable.new()

Constructors

DataItemJoin({int? countValue, String? groupId, String? id, bool? processed, int? result, String? timeProcess, String? timeSend, String? userId})
DataItemJoin.fromJson(Map<String, dynamic> json)
factory

Properties

countValue int?
getter/setter pair
groupId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
processed bool?
getter/setter pair
result int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeProcess String?
getter/setter pair
timeSend String?
getter/setter pair
userId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited