ChatMessageModel class

Annotations
  • @JsonSerializable.new()

Constructors

ChatMessageModel({String? message, String? tempLocalId, String? messageId, String? timeSend, String? senderId, String? roomId, String? quoteFromMessageId, String? forwardFromMessageId, String? forwardFromRoomId, List<AttachmentsModel>? attachments, SenderProfile? senderProfile, int? type, List<String>? mentionIds, bool? isDeleted, bool? isEdited, bool? isSender, String? text, String? time, ChatMessageType? messageType, MessageStatus? messageStatus, String? blockerId, String? id})
@ response in socket message
ChatMessageModel.fromJson(Map<String, dynamic> json)
factory

Properties

attachments List<AttachmentsModel>?
@ list file AttachmentsModel
final
blockerId String?
getter/setter pair
forwardFromMessageId String?
getter/setter pair
forwardFromRoomId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
isDeleted bool?
getter/setter pair
isEdited bool?
getter/setter pair
isSender bool?
getter/setter pair
mentionIds List<String>?
@ list userId mention
final
message String?
getter/setter pair
messageId String?
@ id message
getter/setter pair
messageStatus MessageStatus?
final
messageType ChatMessageType?
final
quoteFromMessageId String?
@ id message for quote
getter/setter pair
roomId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId String?
getter/setter pair
senderProfile SenderProfile?
@ sender profile SenderProfile
final
tempLocalId String?
getter/setter pair
text String?
getter/setter pair
time String?
getter/setter pair
timeSend String?
getter/setter pair
type int?
@ type message list (text = 0, audio = 1, file = 2, sticker = 3, gallery = 4, video = 5)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getTheTypeMessage(int value) ChatMessageType