ApiListMessageResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ApiListMessageResponse({String? id, String? messageContentRaw, String? message, String? timeSend, String? senderId, String? roomId, String? receiperId, String? lastPinedTime, String? lastEditTime, int? type, int? revokeEnum, int? countValue, bool? isDeleted, bool? isEdited, bool? isSave, bool? isPined, List<ReactionsModel>? reactions, List<String>? mentionsIds, List<AttachmentsModel>? attachments})
ApiListMessageResponse.fromJson(Map<String, dynamic> json)
factory

Properties

attachments List<AttachmentsModel>?
final
countValue int?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
@ id message
final
isDeleted bool?
final
isEdited bool?
final
isPined bool?
final
isSave bool?
final
lastEditTime String?
@ ex: 2023-09-28T09:08:34.878Z
final
lastPinedTime String?
@ ex: 2023-09-28T09:08:34.878Z
final
mentionsIds List<String>?
final
message String?
@ content message
final
messageContentRaw String?
@ content message breaf
final
reactions List<ReactionsModel>?
final
receiperId String?
final
revokeEnum int?
final
roomId String?
@ room id
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId String?
@ userId sender
final
timeSend String?
@ ex: 2023-09-28T09:08:34.878Z
final
type int?
@ text = 0, audio = 1, file = 2, sticker = 3, gallery = 4, video = 5
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited