ApiMessageResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ApiMessageResponse({required int skip, required int take, required List<ApiListMessageResponse>? messages, List<ApiUserRoomResponse>? users, String? lastReadMessageId, String? userSendLastRead, String? lastReadMessageTimeSend, String? messageId, String? message, String? textSearch, int? totalCountFinded})
ApiMessageResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lastReadMessageId String?
@ message read lastest
final
lastReadMessageTimeSend String?
@ ex: 2023-09-28T09:08:34.878Z
final
message String?
final
messageId String?
final
messages List<ApiListMessageResponse>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skip int
final
take int
final
textSearch String?
final
totalCountFinded int?
final
users List<ApiUserRoomResponse>?
getter/setter pair
userSendLastRead String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited